/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.parquet;

import java.util.List;
import java.util.stream.Stream;
import org.apache.iceberg.FieldMetrics;
import org.apache.parquet.column.ColumnWriteStore;

public interface ParquetValueWriter<T> {
  void write(int repetitionLevel, T value);

  List<TripleWriter<?>> columns();

  void setColumnStore(ColumnWriteStore columnStore);

  /**
   * Returns a stream of {@link FieldMetrics} that this ParquetValueWriter keeps track of.
   */
  default Stream<FieldMetrics<?>> metrics() {
    return Stream.empty();
  }
}

